<?php
/**
 * Template Name: Portfolio page
 *
 * @package WordPress
 * @subpackage Smarty
 */
get_header(); ?>

<?php
//Portfolio Page Layout 
global $portfolio_style;//register global variable for use of portfolio style in template part

$portfolio_style = rwmb_meta('gg_portfolio_posts_style');
$page_layout = rwmb_meta('gg_page_layout_select');
$page_content_class = 'col-xs-12 col-md-9';
$page_sidebar_class = 'col-xs-12 col-md-3';
$page_layout_width = 'sidebar';

if ($page_layout == 'with_right_sidebar') {

    $page_content_class = 'col-xs-12 col-md-9 pull-left';
    $page_sidebar_class = 'col-xs-12 col-md-3 pull-right';
    $page_layout_width = 'sidebar';

} elseif ($page_layout == 'with_left_sidebar') {

    $page_content_class = 'col-xs-12 col-md-9 pull-right';
    $page_sidebar_class = 'col-xs-12 col-md-3 pull-left';
    $page_layout_width = 'sidebar';

} elseif ($page_layout == 'no_sidebar') {

    $page_content_class = 'col-xs-12 col-md-12';
    $page_layout_width = 'fullwidth';

} elseif ($page_layout == 'fullscreen') {

    $page_content_class = '';

} 

//Portfolio Post Layout
$portfolio_cat_filter = rwmb_meta('gg_portfolio_cat_filter');
$portfolio_col_class = 'col-xs-12 col-sm-6 col-md-3';
$portfolio_col_select = rwmb_meta('gg_portfolio_col_select');
$portfolio_no_posts = rwmb_meta('gg_portfolio_no_posts');
$terms = rwmb_meta( 'gg_portfolio_tax', 'type=taxonomy&taxonomy=portfolio_category' );

//Verify if a term is selected in the backend and get the slug
if (!empty($terms)) {
    $term_slug = $terms[0]->slug;
} else {
    $term_slug = '';
}

switch ($portfolio_col_select) {
    case "four_columns":
        $portfolio_col_class = 'col-xs-12 col-sm-6 col-md-3';
        break;
    case "three_columns":
        $portfolio_col_class = 'col-xs-12 col-sm-6 col-md-4';
        break;
    case "two_columns":
        $portfolio_col_class = 'col-xs-12 col-sm-6 col-md-6';
        break;        
    case "one_column":
        $portfolio_col_class = 'col-xs-12 col-md-12';
        break;    
}

?>

<?php smarty_page_header(); ?>

<?php smarty_page_header_slider(); ?>

<section class="isotope-filter-wrapper">

<?php if($portfolio_cat_filter == '1'){
//Load isotope 
wp_enqueue_script('isotope');
wp_enqueue_style('isotope');
?>

<div class="isotope-filter-handler">
    <div class="container">
        <p data-toggle="collapse" data-target="#isotope-open"><i class="icon_menu-square_alt"></i> <?php _e('Sort Portfolio','okthemes');?></p>
    </div>
</div>

<div id="isotope-open" class="isotope-filter-content collapse in">
    <i class="arrow_triangle-down"></i>
    <div class="container">
        <div class="row">
            <ul data-option-key="filter" id="options" class="clearfix option-set nav nav-pills">
                <li class="col-xs-6 col-sm-3 col-md-2"><a data-option-value="*" href="#filter" class="selected"><?php _e('All','okthemes');?></a></li>
                
                <?php
                    $terms = get_terms('portfolio_category');
                    foreach ( $terms as $term ) {
                       echo '<li class="col-xs-6 col-sm-3 col-md-2"><a data-option-value=".'.$term->slug.'" href="#filter">' . $term->name . ' <span class="badge pull-right visible-lg visible-md">' . $term->count . '</span> </a></li>';
                    }
                ?>

            </ul>
        </div>
    </div>
</div>

<?php } ?>

</section>

<section id="content" <?php echo $page_layout == 'fullscreen' ? 'class="page-fullscreen"' : '' ;?>>
    <?php echo $page_layout == 'fullscreen' ? '' : '<div class="container"><div class="row">' ;?>

        <div class="<?php echo $page_content_class; ?>">
        <!-- Begin portfolio posts -->
        <?php
            //Load magnific 
            wp_enqueue_script('magnific');
            wp_enqueue_style('magnific');

            $paged = get_query_var('paged') ? get_query_var('paged') : 1;

            // WP_Query arguments
            $args = array (
                'post_type'              => 'portfolio_cpt',
                'portfolio_category'     => $term_slug,
                'taxonomy'               => 'portfolio_category',
                'posts_per_page'         => $portfolio_no_posts, 
                'ignore_sticky_posts'    => true,
                'paged'                  => $paged,
            );

            // The Query
            $portfolio_query = new WP_Query( $args );

            // The Loop
            if ( $portfolio_query->have_posts() ) { ?>
            <!-- Verify row class for isotope -->
            <ul class="image-grid row" id="<?php echo $portfolio_cat_filter == '1' ? 'isotope-filter' : '' ;?>">

                <?php while ( $portfolio_query->have_posts() ) : $portfolio_query->the_post(); ?>

                    <li class="<?php echo $portfolio_col_class; ?> element <?php echo gg_tax_terms_slug('portfolio_category');?>" >
                        <?php get_template_part( 'parts/part','portfolio' ); ?>
                    </li><!-- // portfolio item column -->

                <?php endwhile; ?>
            </ul>    

            <?php } else { ?>

                <div class="no-posts-created"> 
                    <h3><?php _e( 'Not Found', 'okthemes' ); ?></h3>  
                    <p><?php _e( 'Sorry, No portfolio posts created yet.', 'okthemes' ); ?></p>  
                </div>
                
            <?php } ?>

            <?php if (function_exists("pagination")) {pagination($portfolio_query->max_num_pages);} ?>

            <?php 
            // Restore original Post Data    
            wp_reset_postdata();
            ?> 

        </div><!-- /.col-8 col-sm-8 col-lg-8 -->

        <?php if (($page_layout !== 'no_sidebar') && ($page_layout !== 'fullscreen')) { ?>
        <div class="<?php echo $page_sidebar_class; ?>">
            <aside class="sidebar-nav">
                <?php get_sidebar(); ?>
            </aside>
            <!--/aside .sidebar-nav -->
        </div><!-- /.col-4 col-sm-4 col-lg-4 -->
        <?php } ?>

    <?php echo $page_layout == 'fullscreen' ? '' : '</div></div>' ;?>    
</section>

<?php smarty_page_footer_message_box(); ?>

<?php get_footer(); ?>